<?php
/**
 * Project:
 * Contenido Content Management System
 *
 * Description:
 * Plug-in "mpHideEmailAddresses" mailto link decryption.
 *
 * Requirements:
 * @con_php_req 5.0
 *
 * @package    Contenido Backend plugins
 * @version    0.1rc
 * @author     Murat Purc <murat@purc.de>
 * @copyright  Murat Purc it-solutions <www.purc.de>
 * @link       http://www.purc.de
 * @license    http://www.contenido.org/license/LIZENZ.txt
 *
 * {@internal
 *   created  2009-05-xx
 *   $Id: mailto.php 244 2011-05-13 14:59:30Z Murat $:
 * }}
 *
 */


defined('CON_FRAMEWORK') or define('CON_FRAMEWORK', true);

################################################################################
##### Initialization

$contenido_path = '';

// include the config file of the frontend to init the Client and Language Id
include_once('config.php');

// include security class and check request variables
// NOTE: it is recommended to enable following lines, if you are using
//       Contenido lower than 4.8.13
//[security_check]
#include_once ($contenido_path . 'classes/class.security.php');
#Contenido_Security::checkRequests();
//[/security_check]

// Contenido startup process
include_once ($contenido_path . 'includes/startup.php');


// get the mailto request parameter
if (!isset($_GET['mailto']) || empty($_GET['mailto'])) {
    return;
}
$mailto = trim(strip_tags($_GET['mailto']));
if (empty($mailto)) {
    return;
}

plugin_include('mpHideEmailAddresses', 'includes/config.plugin.php');

if (true !== $cfg['mpHideEmailAddresses']['enable']) {
    // plug-in is not enabled, get out here
    return;
}

################################################################################
##### Action processing & output

$decrypted = mphea_decrypt($mailto);
$output = '';

if ('raw' == $cfg['mpHideEmailAddresses']['output_mode']) {

    // raw output, redirect to "mailto:user@example.com"
    header('Location: mailto:' . $decrypted);
    exit();

} elseif ('js' == $cfg['mpHideEmailAddresses']['output_mode']) {

    // js output, redirect to "mailto:user@example.com" by using javascript
    $decrypted = base64_encode($decrypted);
    $length = strlen($decrypted);
    for ($i = 0; $i < $length; $i++) {
        $jsMailto .= '"' . addslashes($decrypted[$i]) . '"';
        if ($i < $length - 1) {
            $jsMailto .= ' + ';
        }
    }

/*
Uncopressed version of used javascript function mphea_mailToDecode():
[code]
function mphea_mailToDecode(data) {
    // http://kevin.vanzonneveld.net
    var b64 = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=';
    var o1, o2, o3, h1, h2, h3, h4, bits, i = 0, ac = 0, dec = '', tmp_arr = [];
    if (!data) {
        return data;
    }
    data += '';
    do { // unpack four hexets into three octets using index points in b64
        h1 = b64.indexOf(data.charAt(i++));
        h2 = b64.indexOf(data.charAt(i++));
        h3 = b64.indexOf(data.charAt(i++));
        h4 = b64.indexOf(data.charAt(i++));
        bits = h1 << 18 | h2 << 12 | h3 << 6 | h4;
        o1 = bits >> 16 & 0xff;
        o2 = bits >> 8 & 0xff;
        o3 = bits & 0xff;
        if (h3 == 64) {
            tmp_arr[ac++] = String.fromCharCode(o1);
        } else if (h4 == 64) {
            tmp_arr[ac++] = String.fromCharCode(o1, o2);
        } else {
            tmp_arr[ac++] = String.fromCharCode(o1, o2, o3);
        }
    } while (i < data.length);
    dec = tmp_arr.join('');
    //dec = this.utf8_decode(dec);
    return dec;
}
[/code]
*/
    $output = <<<HTML
<html>
<head>
    <title></title>
    <script type="text/javascript"><!--
    function mphea_mailToDecode(data){var b64='ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=';var o1,o2,o3,h1,h2,h3,h4,bits,i=0,ac=0,dec='',tmp_arr=[];if(!data){return data;}
    data+='';do{h1=b64.indexOf(data.charAt(i++));h2=b64.indexOf(data.charAt(i++));h3=b64.indexOf(data.charAt(i++));h4=b64.indexOf(data.charAt(i++));bits=h1<<18|h2<<12|h3<<6|h4;o1=bits>>16&0xff;o2=bits>>8&0xff;o3=bits&0xff;if(h3==64){tmp_arr[ac++]=String.fromCharCode(o1);}else if(h4==64){tmp_arr[ac++]=String.fromCharCode(o1,o2);}else{tmp_arr[ac++]=String.fromCharCode(o1,o2,o3);}}while(i<data.length);dec=tmp_arr.join('');return dec;}
    --></script>
    <script type="text/javascript"><!--
    document.location.href = "mailto:" + mphea_mailToDecode({$jsMailto});
    --></script>
</head>
<body>
<script type="text/javascript"><!--
document.write(mphea_mailToDecode({$jsMailto}));
--></script>
</body>
</html>
HTML;

    echo $output;

}
