<?php
/**
 * Project:
 * Contenido Content Management System
 *
 * Description:
 * Plug-in "mpHideEmailAddresses" functions.
 *
 * Requirements:
 * @con_php_req 5.0
 *
 *
 * @package    Contenido Backend plugins
 * @version    0.1rc
 * @author     Murat Purc <murat@purc.de>
 * @copyright  Murat Purc it-solutions <www.purc.de>
 * @link       http://www.purc.de
 * @license    http://www.contenido.org/license/LIZENZ.txt
 *
 * {@internal
 *   created  2009-05-xx
 *   $Id: functions.php 243 2011-05-13 14:33:24Z Murat $:
 * }}
 *
 */


defined('CON_FRAMEWORK') or die('Illegal call');


/**
 * Replaces the mailto links in passed code
 *
 * @param   string  $code
 * @return  string  The processed code
 */
function mphea_chainHTMLCodeOutput($code)
{
    global $cfg;
    $res = preg_match_all('/(\'|")(mailto:)([a-zA-Z@0-9\.\+]{1,})(\'|")/ims', $code, $patterns);

    // $patterns[0][pos] = matching string e. g. 'mailto:user@domain.com' or "mailto:user@domain.com"
    // $patterns[1][pos] = starting quote ' or "
    // $patterns[2][pos] = mailto:
    // $patterns[3][pos] = user@domain.com
    // $patterns[4][pos] = ending quote ' or "

    if (is_array($patterns[0]) && count($patterns[0]) > 0) {
        foreach ($patterns[0] as $p => $match) {
            $mail = $patterns[3][$p];
            if (empty($mail)) {
                continue;
            }
            $mail    = urlencode(mphea_encrypt($mail));
            if ('js' == $cfg['mpHideEmailAddresses']['output_mode']) {
                $jsQuote = ('"' == $patterns[1][$p]) ? "'" : '"';
                $replace = $patterns[1][$p] . 'javascript:window.open(' . $jsQuote . $cfg['mpHideEmailAddresses']['mailtoUrl'] . $mail . $jsQuote . ');' . $patterns[4][$p];
            } else {
                $replace = $patterns[1][$p] . $cfg['mpHideEmailAddresses']['mailtoUrl'] . $mail . $patterns[4][$p];
            }
            $code    = str_replace($match, $replace, $code);
        }
    }
    return $code;
}


/**
 * Encrypts passed string by using configured magic key
 *
 * @param   string  $string
 * @return  string
 */
function mphea_encrypt($string)
{
    global $cfg;
    $key    = $cfg['mpHideEmailAddresses']['magickey'];
    $result = '';
    for ($i=0; $i<strlen($string); $i++) {
        $char    = substr($string, $i, 1);
        $keychar = substr($key, ($i % strlen($key))-1, 1);
        $char    = chr(ord($char) + ord($keychar));
        $result .= $char;
    }
    return base64_encode($result);
}


/**
 * Decrypts passed string by using configured magic key
 *
 * @param   string  $string
 * @return  string
 */
function mphea_decrypt($string)
{
    global $cfg;
    $key    = $cfg['mpHideEmailAddresses']['magickey'];
    $result = '';
    $string = base64_decode($string);
    for ($i=0; $i<strlen($string); $i++) {
        $char    = substr($string, $i, 1);
        $keychar = substr($key, ($i % strlen($key))-1, 1);
        $char    = chr(ord($char) - ord($keychar));
        $result .= $char;
    }
    return $result;
}


/**
 * Checks if the plug-in is enabled.
 * @return bool
 */
function mphea_isEnabled()
{
    global $cfg, $idart, $idcat;

    if (false === $cfg['mpHideEmailAddresses']['enable']) {
        return false;
    }

    if (isset($idcat) && in_array($idcat, $cfg['mpHideEmailAddresses']['disableIdcats'])) {
        return false;
    }

    if (isset($idart) && in_array($idart, $cfg['mpHideEmailAddresses']['disableIdarts'])) {
        return false;
    }

    return true;
}